// Copyright 2026 The Sigstore Authors.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package bundle

// Option configures optional behaviour when constructing a Bundle.
type Option func(*Bundle)

// AllowCertificateChain permits bundles with version >= v0.3 to contain
// X.509 certificate chains in their verification material. By default,
// v0.3+ bundles require a single certificate rather than a chain.
func AllowCertificateChain() Option {
	return func(b *Bundle) {
		b.allowCertificateChain = true
	}
}
